import { useState, useEffect, useMemo, memo, useRef } from "react";
import AuthModal from "./AuthModal";
import { motion, useAnimation } from "framer-motion";
import { useLocation } from "wouter";
import { useAuth } from "@/hooks/useAuth";
import heroBackgroundImage from "../assets/fondo.webp";

// Componente de efectos estáticos optimizado para rendimiento máximo en carga inicial
// Especialmente importante para dispositivos móviles
const OptimizedStaticEffect = memo(function OptimizedStaticEffect() {
  // Reducido a sólo 3 elementos estáticos para renderizado extremadamente rápido
  // Versión ultraligera para primera carga
  return (
    <div className="optimized-effects absolute inset-0 overflow-hidden pointer-events-none">
      <div 
        className="absolute rounded-full animate-pulse-slow"
        style={{
          background: 'radial-gradient(circle, rgba(137,221,255,0.2) 0%, rgba(58,134,255,0.05) 100%)',
          width: '8px',
          height: '8px',
          left: '25%',
          top: '30%',
          opacity: 0.6,
        }}
      />
      <div 
        className="absolute rounded-full animate-pulse-slow-delayed"
        style={{
          background: 'radial-gradient(circle, rgba(137,221,255,0.2) 0%, rgba(58,134,255,0.05) 100%)',
          width: '10px',
          height: '10px',
          right: '25%',
          bottom: '40%',
          opacity: 0.7,
        }}
      />
      <div 
        className="absolute rounded-full animate-float-minimal"
        style={{
          background: 'radial-gradient(circle, rgba(137,221,255,0.15) 0%, rgba(58,134,255,0.05) 100%)',
          width: '6px',
          height: '6px',
          right: '35%',
          top: '25%',
          opacity: 0.5,
        }}
      />
    </div>
  );
});

// Componente simplificado para efectos ligeros, optimizado para dispositivos móviles
const LightweightEffects = memo(function LightweightEffects() {
  // Usamos useState y useEffect para detectar si estamos en móvil
  const [isMobile, setIsMobile] = useState(false);
  
  // Detectar móvil solo del lado del cliente
  useEffect(() => {
    const checkMobile = () => {
      setIsMobile(window.innerWidth < 768);
    };
    
    // Detectar inicialmente
    checkMobile();
    
    // Actualizar en cambio de tamaño de ventana
    window.addEventListener('resize', checkMobile);
    return () => window.removeEventListener('resize', checkMobile);
  }, []);
  
  // En móviles, solo mostrar el elemento de brillo estático más simple
  if (isMobile) {
    return (
      <div className="lightweight-glow absolute w-full h-full pointer-events-none">
        <div 
          className="absolute rounded-full"
          style={{
            background: 'radial-gradient(circle, rgba(123,90,255,0.15) 0%, rgba(73,61,138,0) 70%)',
            width: '200px',
            height: '200px',
            top: '30%',
            left: '50%',
            transform: 'translateX(-50%)',
            opacity: 0.3,
          }}
        />
      </div>
    );
  }
  
  // En desktop, podemos agregar un simple efecto de pulso
  return (
    <div className="lightweight-effects pointer-events-none">
      <motion.div
        className="absolute rounded-full"
        style={{
          background: 'radial-gradient(circle, rgba(123,90,255,0.15) 0%, rgba(73,61,138,0) 70%)',
          width: '300px',
          height: '300px',
          top: '20%',
          left: '10%',
        }}
        animate={{ 
          scale: [1, 1.1, 1],
          opacity: [0.2, 0.3, 0.2],
        }}
        transition={{
          repeat: Infinity,
          duration: 10,
          ease: "easeInOut",
        }}
      />
    </div>
  );
});

// Componente para los elementos brillantes (memoizado y optimizado)
const GlowElements = memo(function GlowElements() {
  // Solo un elemento de brillo grande para reducir carga de renderizado
  return (
    <div className="glow-elements pointer-events-none">
      <motion.div
        className="absolute w-[25rem] h-[25rem] rounded-full"
        style={{
          background: 'radial-gradient(circle, rgba(123,90,255,0.15) 0%, rgba(73,61,138,0) 70%)',
          top: '20%',
          left: '10%',
          willChange: 'transform, opacity', // Optimización de rendimiento
        }}
        initial={{ scale: 1, opacity: 0.3 }}
        animate={{
          scale: [1, 1.12, 1],
          opacity: [0.25, 0.4, 0.25],
        }}
        transition={{
          repeat: Infinity,
          duration: 12, // Duración más larga para menos actualización de frames
          ease: "easeInOut",
          // Sin delay para iniciar inmediatamente
        }}
      />
    </div>
  );
});

// Componente para las líneas digitales (memoizado y optimizado)
const NetworkLines = memo(function NetworkLines() {
  // Reducimos el número de líneas de 4 a 3 y pre-calculamos todas las propiedades
  const lines = useMemo(() => {
    // Conjunto predefinido de líneas para minimizar cálculos aleatorios
    return [
      {
        x1: 20,
        y1: 30,
        x2: 80,
        y2: 70,
        duration: 8,
        delay: 0,
        stroke: "rgba(156, 226, 255, 0.4)"
      },
      {
        x1: 70,
        y1: 20,
        x2: 30,
        y2: 80,
        duration: 10,
        delay: 2,
        stroke: "rgba(156, 226, 255, 0.3)"
      },
      {
        x1: 40,
        y1: 15,
        x2: 60,
        y2: 85,
        duration: 12,
        delay: 4,
        stroke: "rgba(156, 226, 255, 0.2)"
      }
    ];
  }, []);

  return (
    <svg 
      className="absolute inset-0 w-full h-full z-0 opacity-25" 
      viewBox="0 0 100 100" 
      preserveAspectRatio="none"
      style={{ willChange: 'opacity' }} // Optimización de rendimiento
    >
      {lines.map((line, i) => (
        <motion.line
          key={i}
          x1={line.x1}
          y1={line.y1}
          x2={line.x2}
          y2={line.y2}
          stroke={line.stroke}
          strokeWidth="0.2"
          initial={{ opacity: 0.1 }}
          animate={{
            opacity: [0.1, 0.3, 0.1]
          }}
          transition={{
            repeat: Infinity,
            duration: line.duration,
            ease: "easeInOut",
            delay: line.delay
          }}
        />
      ))}
    </svg>
  );
});

export default function Hero() {
  const { user } = useAuth();
  const [, setLocation] = useLocation();
  const [showAuthModal, setShowAuthModal] = useState(false);
  // Estados para el nuevo carrusel de testimonios
  const [currentTestimonial, setCurrentTestimonial] = useState(0);
  const [autoplayActive, setAutoplayActive] = useState(true);
  const [isAnimating, setIsAnimating] = useState(false);
  
  // Array de testimonios
  const testimonials = [
    {
      id: 1,
      text: "Runalya me ha ayudado a encontrar claridad en momentos difíciles. Las predicciones fueron sorprendentemente certeras y me orientaron hacia decisiones más conscientes.",
      author: "Alberto M.",
      location: "Barcelona",
      type: "Usuario desde 2024",
      stars: 5,
      initials: "AM"
    },
    {
      id: 2,
      text: "La lectura de runas me dio perspectivas que nunca había considerado. Me sorprendió cómo identificó patrones en mi vida que ni yo mismo había notado.",
      author: "Laura C.",
      location: "Valencia",
      type: "Usuario Premium",
      stars: 5,
      initials: "LC"
    },
    {
      id: 3,
      text: "Utilizo el horóscopo diario para organizar mi agenda. Me ha ayudado a planificar mejor mis días y aprovechar las energías favorables para diferentes actividades.",
      author: "Javier R.",
      location: "Sevilla",
      type: "Usuario",
      stars: 4,
      initials: "JR"
    },
    {
      id: 4,
      text: "El análisis de compatibilidad me ayudó a entender mejor mi relación. Los consejos prácticos mejoraron nuestra comunicación y descubrimos aspectos complementarios.",
      author: "Carmen P.",
      location: "Málaga",
      type: "Usuario Premium",
      stars: 5,
      initials: "CP"
    },
    {
      id: 5,
      text: "La consulta de quiromancia me dio una perspectiva nueva sobre mis talentos. Me ha motivado a desarrollar habilidades que tenía abandonadas.",
      author: "Daniel T.",
      location: "Zaragoza",
      type: "Usuario",
      stars: 5,
      initials: "DT"
    }
  ];
  
  // Optimizamos las animaciones usando useAnimation 
  const controls = useAnimation();
  const testimonialControls = useAnimation();
  
  // Referencia para rastrear si el componente está montado
  const isMounted = useRef(false);
  
  // Inicializamos las animaciones cuando el componente está montado
  useEffect(() => {
    // Marcar el componente como montado
    isMounted.current = true;
    
    // Solo iniciar animaciones si el componente está montado
    if (isMounted.current) {
      controls.start({
        opacity: 1,
        y: 0,
        transition: { duration: 0.7 }
      });
    }
    
    // Cleanup: marcar como desmontado cuando el componente se desmonte
    return () => {
      isMounted.current = false;
    };
  }, [controls]);
  
  // Función para navegar al siguiente testimonio - corregida para evitar error de animación
  const nextTestimonial = () => {
    if (isAnimating || !isMounted.current) return;
    
    setIsAnimating(true);
    
    try {
      // Primera animación (desvanecimiento)
      testimonialControls.start({
        opacity: [1, 0],
        x: [0, 20],
        transition: { duration: 0.3 }
      }).then(() => {
        if (!isMounted.current) return;
        
        // Actualizar el testimonio actual
        setCurrentTestimonial((prev) => (prev + 1) % testimonials.length);
        
        // Usar requestAnimationFrame en lugar de setTimeout para mejor rendimiento
        requestAnimationFrame(() => {
          if (!isMounted.current) return;
          
          // Segunda animación (aparición)
          testimonialControls.start({
            opacity: [0, 1],
            x: [-20, 0],
            transition: { duration: 0.3 }
          }).then(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          }).catch(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          });
        });
      }).catch(() => {
        if (!isMounted.current) return;
        setIsAnimating(false);
      });
    } catch (error) {
      console.error("Error al animar testimonio:", error);
      if (isMounted.current) {
        setIsAnimating(false);
      }
    }
  };
  
  // Función para navegar al testimonio anterior - corregida usando la misma lógica segura
  const prevTestimonial = () => {
    if (isAnimating || !isMounted.current) return;
    
    setIsAnimating(true);
    
    try {
      // Primera animación (desvanecimiento)
      testimonialControls.start({
        opacity: [1, 0],
        x: [0, -20],
        transition: { duration: 0.3 }
      }).then(() => {
        if (!isMounted.current) return;
        
        // Actualizar el testimonio actual
        setCurrentTestimonial((prev) => (prev - 1 + testimonials.length) % testimonials.length);
        
        // Usar requestAnimationFrame en lugar de setTimeout
        requestAnimationFrame(() => {
          if (!isMounted.current) return;
          
          // Segunda animación (aparición)
          testimonialControls.start({
            opacity: [0, 1],
            x: [20, 0],
            transition: { duration: 0.3 }
          }).then(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          }).catch(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          });
        });
      }).catch(() => {
        if (!isMounted.current) return;
        setIsAnimating(false);
      });
    } catch (error) {
      console.error("Error al animar testimonio:", error);
      if (isMounted.current) {
        setIsAnimating(false);
      }
    }
  };
  
  // Función para ir a un testimonio específico - corregida para prevenir error de montaje
  const goToTestimonial = (index: number) => {
    if (isAnimating || index === currentTestimonial || !isMounted.current) return;
    
    setIsAnimating(true);
    
    try {
      // Primera animación (desvanecimiento)
      testimonialControls.start({
        opacity: [1, 0],
        scale: [1, 0.95],
        transition: { duration: 0.3 }
      }).then(() => {
        if (!isMounted.current) return;
        
        // Actualizar el testimonio actual
        setCurrentTestimonial(index);
        
        // Usar requestAnimationFrame para mejor rendimiento
        requestAnimationFrame(() => {
          if (!isMounted.current) return;
          
          // Segunda animación (aparición)
          testimonialControls.start({
            opacity: [0, 1],
            scale: [0.95, 1],
            transition: { duration: 0.3 }
          }).then(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          }).catch(() => {
            if (!isMounted.current) return;
            setIsAnimating(false);
          });
        });
      }).catch(() => {
        if (!isMounted.current) return;
        setIsAnimating(false);
      });
    } catch (error) {
      console.error("Error al animar testimonio:", error);
      if (isMounted.current) {
        setIsAnimating(false);
      }
    }
  };
  
  // Autoplay para cambiar testimonios automáticamente - usa referencia global
  useEffect(() => {
    let intervalId: NodeJS.Timeout | undefined;
    
    if (autoplayActive && isMounted.current) {
      intervalId = setInterval(() => {
        if (!isAnimating && isMounted.current) {
          // Prevenir llamadas a setState en componentes desmontados
          try {
            nextTestimonial();
          } catch (error) {
            console.error("Error en autoplay:", error);
            // Limpiamos el intervalo si hay error
            if (intervalId) {
              clearInterval(intervalId);
            }
          }
        }
      }, 5000); // Cambiar cada 5 segundos
    }
    
    // Cleanup
    return () => {
      if (intervalId) {
        clearInterval(intervalId);
      }
    };
  }, [autoplayActive, currentTestimonial, isAnimating]);
  
  const container = {
    hidden: { opacity: 0 },
    show: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2
      }
    }
  };
  
  const item = {
    hidden: { y: 20, opacity: 0 },
    show: { y: 0, opacity: 1 }
  };

  return (
    <section className="relative min-h-screen flex items-center justify-center py-16 px-4 md:py-20 lg:py-28 overflow-hidden">
      {/* Background image preoptimizado para carga rápida */}
      <div 
        className="absolute inset-0 z-0 bg-purple-900/30" 
        style={{
          backgroundImage: `url(${heroBackgroundImage})`,
          backgroundSize: 'cover',
          backgroundPosition: 'center',
          backgroundRepeat: 'no-repeat',
          opacity: 0.9,
          willChange: 'opacity',
        }}
      />
      
      {/* Overlay optimizado para rendimiento extremo */}
      <div 
        className="absolute inset-0 z-0 bg-gradient-to-br from-purple-900/80 via-night/70 to-blue-900/80 bg-gradient-flow"
        style={{ 
          backdropFilter: 'brightness(0.7)',
          backgroundSize: '300% 300%',
          overflow: 'hidden'
        }}
      >
        {/* Efectos optimizados para carga inicial */}
        <OptimizedStaticEffect />
        
        {/* Cargar efectos simplificados para mejor rendimiento */}
        <LightweightEffects />
      </div>
      
      {/* CSS Keyframes for gradients - Optimizados con will-change */}
      <style dangerouslySetInnerHTML={{
        __html: `
          @keyframes gradientFlow {
            0% { background-position: 0% 50% }
            50% { background-position: 100% 50% }
            100% { background-position: 0% 50% }
          }
          .bg-gradient-flow {
            animation: gradientFlow 15s ease infinite;
            will-change: background-position;
          }
          /* Clase para texto pequeño en dispositivos muy pequeños */
          .text-2xs {
            font-size: 0.7rem;
            line-height: 1rem;
          }
        `
      }} />
      
      <div className="relative z-10 container mx-auto px-2 sm:px-4 md:px-6 text-center w-full">
        <motion.div
          variants={container}
          initial="hidden"
          animate="show"
          className="pt-16 sm:pt-20 md:pt-24 lg:pt-28 w-full"
        >
          <motion.h1 
            variants={item} 
            className="font-playfair text-2xl xs:text-3xl sm:text-4xl md:text-5xl lg:text-6xl xl:text-7xl mb-3 sm:mb-4 md:mb-5 lg:mb-6 leading-tight px-1"
          >
            Revela tu <span className="text-celestial">Verdadero Destino</span> con Runalya
          </motion.h1>
          
          <motion.p 
            variants={item} 
            className="text-sm xs:text-base sm:text-lg md:text-xl lg:text-2xl max-w-xs xs:max-w-sm sm:max-w-xl md:max-w-2xl lg:max-w-3xl mx-auto mb-4 sm:mb-6 md:mb-8 px-2"
          >
            El poder del universo y la precisión de la IA, unidos para transformar tu vida
          </motion.p>
          
          <motion.div
            variants={item}
            className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-3 xs:gap-4 max-w-xs xs:max-w-sm sm:max-w-2xl md:max-w-3xl lg:max-w-4xl mx-auto mb-6 sm:mb-8 md:mb-10 lg:mb-16"
          >
            <div className="backdrop-blur-sm bg-indigo-900/20 rounded-lg p-3 sm:p-4 border border-indigo-500/30 flex flex-col items-center transform transition-all hover:scale-105">
              <span className="text-lg sm:text-xl text-amber-300 mb-1 sm:mb-2">✧</span>
              <h3 className="text-base sm:text-lg font-medium mb-0.5 sm:mb-1">Análisis Profundo</h3>
              <p className="text-xs sm:text-sm text-sky-100/80">Interpretaciones personalizadas que revelan verdades ocultas sobre tu camino</p>
            </div>
            
            <div className="backdrop-blur-sm bg-indigo-900/20 rounded-lg p-3 sm:p-4 border border-indigo-500/30 flex flex-col items-center transform transition-all hover:scale-105">
              <span className="text-lg sm:text-xl text-amber-300 mb-1 sm:mb-2">✧</span>
              <h3 className="text-base sm:text-lg font-medium mb-0.5 sm:mb-1">Precisión Mística</h3>
              <p className="text-xs sm:text-sm text-sky-100/80">Combinamos tradición ancestral con tecnología avanzada para lecturas inigualables</p>
            </div>
            
            <div className="backdrop-blur-sm bg-indigo-900/20 rounded-lg p-3 sm:p-4 border border-indigo-500/30 flex flex-col items-center transform transition-all hover:scale-105 sm:col-span-2 lg:col-span-1">
              <span className="text-lg sm:text-xl text-amber-300 mb-1 sm:mb-2">✧</span>
              <h3 className="text-base sm:text-lg font-medium mb-0.5 sm:mb-1">Orientación Diaria</h3>
              <p className="text-xs sm:text-sm text-sky-100/80">Guía personalizada para enfrentar los desafíos y aprovechar las oportunidades cósmicas</p>
            </div>
          </motion.div>
          
          <motion.div 
            variants={item} 
            className="flex flex-col xs:flex-row gap-3 xs:gap-4 sm:gap-6 justify-center items-center"
          >
            <motion.button 
              onClick={() => user ? setLocation("/profile") : setShowAuthModal(true)}
              className="relative overflow-hidden backdrop-blur-[4px] px-6 xs:px-8 sm:px-10 md:px-12 py-2.5 xs:py-3 sm:py-3.5 md:py-4 text-sm xs:text-base sm:text-lg w-full xs:w-auto"
              whileHover={{ scale: 1.03 }}
              whileTap={{ scale: 0.98 }}
              style={{
                clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)",
                maxWidth: "280px"
              }}
            >
              {/* Button background with glow and pulse */}
              <motion.div 
                className="absolute inset-0 bg-gradient-to-r from-indigo-600 to-purple-600"
                animate={{
                  background: [
                    "linear-gradient(to right, rgb(79, 70, 229), rgb(124, 58, 237))",
                    "linear-gradient(to right, rgb(99, 102, 241), rgb(139, 92, 246))",
                    "linear-gradient(to right, rgb(79, 70, 229), rgb(124, 58, 237))"
                  ]
                }}
                transition={{
                  duration: 3,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
              />
              
              {/* Inner shape glow */}
              <motion.div 
                className="absolute inset-[2px] opacity-50"
                style={{
                  clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)",
                  background: "linear-gradient(45deg, rgba(79, 70, 229, 0.4) 0%, rgba(124, 58, 237, 0.1) 100%)"
                }}
                animate={{
                  opacity: [0.3, 0.5, 0.3]
                }}
                transition={{
                  duration: 2,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
              />
              
              {/* Shimmering edge */}
              <motion.div 
                className="absolute inset-0 opacity-0"
                animate={{
                  background: [
                    "linear-gradient(45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 45%, rgba(255,255,255,0.1) 50%, rgba(255,255,255,0) 55%, rgba(255,255,255,0) 100%)",
                    "linear-gradient(45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 40%, rgba(255,255,255,0.3) 50%, rgba(255,255,255,0) 60%, rgba(255,255,255,0) 100%)",
                    "linear-gradient(45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 45%, rgba(255,255,255,0.1) 50%, rgba(255,255,255,0) 55%, rgba(255,255,255,0) 100%)"
                  ],
                  opacity: [0, 1, 0]
                }}
                transition={{
                  duration: 3,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
              />
              
              {/* Text with shine effect */}
              <span className="relative z-10 font-medium text-white inline-flex items-center justify-center">
                <motion.span
                  className="absolute inset-0 w-0 h-full bg-gradient-to-r from-transparent via-white/50 to-transparent"
                  animate={{
                    width: ["0%", "100%", "0%"],
                    left: ["-20%", "120%", "120%"]
                  }}
                  transition={{
                    duration: 1.5,
                    repeat: Infinity,
                    repeatDelay: 2
                  }}
                />
                {user ? "Mi Perfil" : "Comenzar Gratis"}
              </span>
            </motion.button>
            
            <a href="#premium" className="inline-block w-full xs:w-auto">
              <motion.button 
                className="relative overflow-hidden backdrop-blur-[4px] px-6 xs:px-8 sm:px-10 md:px-12 py-2.5 xs:py-3 sm:py-3.5 md:py-4 text-sm xs:text-base sm:text-lg w-full"
                whileHover={{ scale: 1.03 }}
                whileTap={{ scale: 0.98 }}
                style={{
                  clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)",
                  maxWidth: "280px"
                }}
              >
                {/* Button border with gradient - Dynamic gold/amber */}
                <motion.div 
                  className="absolute inset-0"
                  animate={{
                    background: [
                      "linear-gradient(to right, #f59e0b, #d97706)",
                      "linear-gradient(to right, #fbbf24, #f59e0b)",
                      "linear-gradient(to right, #f59e0b, #d97706)"
                    ]
                  }}
                  transition={{
                    duration: 3,
                    repeat: Infinity,
                    ease: "easeInOut"
                  }}
                ></motion.div>
                
                {/* Inner background with subtle gradient */}
                <div className="absolute inset-[2px] bg-gradient-to-br from-amber-400 to-amber-500"
                  style={{
                    clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
                  }}
                />
                
                {/* Animated glow effect */}
                <motion.div 
                  className="absolute inset-0 bg-gradient-to-r from-celestial/0 via-celestial/20 to-celestial/0"
                  animate={{
                    x: ["-100%", "100%"]
                  }}
                  transition={{
                    duration: 4,
                    repeat: Infinity,
                    ease: "easeInOut"
                  }}
                />
                
                {/* Text with diamond icon */}
                <div className="relative z-10 font-medium text-white flex items-center justify-center">
                  <motion.span 
                    animate={{ 
                      textShadow: [
                        "0 0 8px rgba(0, 0, 0, 0.2)",
                        "0 0 15px rgba(0, 0, 0, 0.4)",
                        "0 0 8px rgba(0, 0, 0, 0.2)"
                      ] 
                    }}
                    transition={{
                      duration: 2,
                      repeat: Infinity,
                      ease: "easeInOut"
                    }}
                  >
                    Explorar Premium
                  </motion.span>
                  <motion.span 
                    className="ml-2 text-xl" 
                    animate={{ 
                      scale: [1, 1.2, 1],
                      rotate: [0, 15, 0, -15, 0],
                      opacity: [0.7, 1, 0.7]
                    }}
                    transition={{
                      duration: 3,
                      repeat: Infinity,
                      ease: "easeInOut"
                    }}
                  >
                    ⋄
                  </motion.span>
                </div>
              </motion.button>
            </a>
          </motion.div>
        </motion.div>
        
        {/* Testimonial Section */}
        <motion.div
          initial={{ opacity: 0, y: 30 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ delay: 0.7, duration: 0.6 }}
          className="my-8 sm:my-12 md:my-16"
        >
          <div className="max-w-xs xs:max-w-sm sm:max-w-xl md:max-w-3xl lg:max-w-4xl mx-auto px-2 sm:px-4">
            <h3 className="text-lg sm:text-xl font-medium mb-4 sm:mb-6 text-center">Lo que dicen nuestros usuarios</h3>
            
            {/* Testimonial Carousel - Optimized Version */}
            <div className="relative max-w-xs xs:max-w-sm sm:max-w-xl md:max-w-3xl lg:max-w-4xl mx-auto">
              {/* Carousel Container */}
              <div className="overflow-hidden rounded-xl">
                <motion.div 
                  className="relative p-4 sm:p-6 md:p-8 min-h-[220px] sm:min-h-[240px] md:min-h-[260px]"
                  initial={{ opacity: 1 }}
                  animate={testimonialControls}
                >
                  {/* Background Blur */}
                  <div className="absolute inset-0 bg-indigo-600/10 backdrop-blur-sm rounded-xl border border-indigo-500/20"></div>
                  
                  {/* Testimonial Content */}
                  <div className="relative flex flex-col h-full">
                    <div className="flex mb-2 sm:mb-4 justify-center">
                      {[...Array(testimonials[currentTestimonial].stars)].map((_, i) => (
                        <span key={i} className="text-amber-300 text-base sm:text-lg mx-0.5">★</span>
                      ))}
                      {testimonials[currentTestimonial].stars < 5 && (
                        [...Array(5 - testimonials[currentTestimonial].stars)].map((_, i) => (
                          <span key={i} className="text-amber-300/50 text-base sm:text-lg mx-0.5">★</span>
                        ))
                      )}
                    </div>
                    <p className="text-sm sm:text-base md:text-lg italic mb-3 sm:mb-4 leading-relaxed text-center flex-grow">
                      "{testimonials[currentTestimonial].text}"
                    </p>
                    <div className="flex items-center justify-center mt-auto">
                      <div className="w-8 h-8 sm:w-10 sm:h-10 rounded-full bg-gradient-to-br from-purple-500 to-indigo-600 flex items-center justify-center text-white text-sm sm:text-base font-medium">
                        {testimonials[currentTestimonial].initials}
                      </div>
                      <div className="ml-2 sm:ml-3 text-left">
                        <p className="font-medium text-sm sm:text-base">{testimonials[currentTestimonial].author}</p>
                        <p className="text-xs sm:text-sm text-indigo-200/80">{testimonials[currentTestimonial].type} • {testimonials[currentTestimonial].location}</p>
                      </div>
                    </div>
                  </div>
                </motion.div>
              </div>
              
              {/* Navigation Arrows */}
              <div className="absolute -left-1 sm:-left-3 md:-left-6 top-1/2 transform -translate-y-1/2 z-10">
                <button 
                  onClick={prevTestimonial}
                  className="flex items-center justify-center w-8 h-8 sm:w-10 sm:h-10 rounded-full bg-indigo-600/20 backdrop-blur-sm border border-indigo-500/30 hover:bg-indigo-600/30 transition-colors"
                  aria-label="Testimonio anterior"
                  disabled={isAnimating}
                >
                  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-4 h-4 sm:w-5 sm:h-5">
                    <path fillRule="evenodd" d="M7.72 12.53a.75.75 0 010-1.06l7.5-7.5a.75.75 0 111.06 1.06L9.31 12l6.97 6.97a.75.75 0 11-1.06 1.06l-7.5-7.5z" clipRule="evenodd" />
                  </svg>
                </button>
              </div>
              
              <div className="absolute -right-1 sm:-right-3 md:-right-6 top-1/2 transform -translate-y-1/2 z-10">
                <button 
                  onClick={nextTestimonial}
                  className="flex items-center justify-center w-8 h-8 sm:w-10 sm:h-10 rounded-full bg-indigo-600/20 backdrop-blur-sm border border-indigo-500/30 hover:bg-indigo-600/30 transition-colors"
                  aria-label="Siguiente testimonio"
                  disabled={isAnimating}
                >
                  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-4 h-4 sm:w-5 sm:h-5">
                    <path fillRule="evenodd" d="M16.28 11.47a.75.75 0 010 1.06l-7.5 7.5a.75.75 0 01-1.06-1.06L14.69 12 7.72 5.03a.75.75 0 011.06-1.06l7.5 7.5z" clipRule="evenodd" />
                  </svg>
                </button>
              </div>
            </div>
            
            {/* Slide Controls */}
            <div className="flex justify-center items-center mt-4 sm:mt-6">
              <div className="flex space-x-2 sm:space-x-3">
                {testimonials.map((_, i) => (
                  <button
                    key={i}
                    onClick={() => goToTestimonial(i)}
                    className={`w-2 h-2 sm:w-2.5 sm:h-2.5 rounded-full transition-all duration-300 ${
                      currentTestimonial === i ? 'bg-indigo-400 scale-110' : 'bg-indigo-400/30 hover:bg-indigo-400/50'
                    }`}
                    aria-label={`Ir al testimonio ${i + 1}`}
                    disabled={isAnimating}
                  />
                ))}
              </div>
              
              <button 
                onClick={() => setAutoplayActive(!autoplayActive)}
                className="flex items-center justify-center w-6 h-6 sm:w-8 sm:h-8 rounded-full bg-indigo-600/20 backdrop-blur-sm border border-indigo-500/30 hover:bg-indigo-600/30 transition-colors ml-4 sm:ml-6"
                aria-label={autoplayActive ? "Pausar autoplay" : "Activar autoplay"}
              >
                {autoplayActive ? (
                  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-3 h-3 sm:w-4 sm:h-4">
                    <path fillRule="evenodd" d="M6.75 5.25a.75.75 0 01.75-.75H9a.75.75 0 01.75.75v13.5a.75.75 0 01-.75.75H7.5a.75.75 0 01-.75-.75V5.25zm7.5 0A.75.75 0 0115 4.5h1.5a.75.75 0 01.75.75v13.5a.75.75 0 01-.75.75H15a.75.75 0 01-.75-.75V5.25z" clipRule="evenodd" />
                  </svg>
                ) : (
                  <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-3 h-3 sm:w-4 sm:h-4">
                    <path fillRule="evenodd" d="M4.5 5.653c0-1.426 1.529-2.33 2.779-1.643l11.54 6.348c1.295.712 1.295 2.573 0 3.285L7.28 19.991c-1.25.687-2.779-.217-2.779-1.643V5.653z" clipRule="evenodd" />
                  </svg>
                )}
              </button>
            </div>
          </div>
        </motion.div>
        
        <motion.div 
          initial={{ opacity: 0, y: 50 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ delay: 0.8, duration: 0.6 }}
          className="flex justify-center mt-8 sm:mt-12"
        >
          <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-5 gap-5 sm:gap-6 text-center">
            <a href="#horoscopo" className="block group">
              <motion.div 
                whileHover={{ 
                  scale: 1.08,
                  transition: { type: "spring", stiffness: 400, damping: 10 }
                }}
                className="flex flex-col items-center"
              >
                <div className="w-16 h-16 sm:w-20 sm:h-20 relative">
                  {/* Hexagon background with glow effect */}
                  <svg className="absolute inset-0" viewBox="0 0 100 100" fill="none">
                    <motion.path 
                      d="M50 0L93.3 25V75L50 100L6.7 75V25L50 0Z"
                      className="fill-indigo-900/30 stroke-white"
                      strokeWidth="1.5"
                      animate={{
                        strokeWidth: ["1.5", "2.5", "1.5"],
                        filter: ["drop-shadow(0 0 2px rgba(255,255,255,0.5))", "drop-shadow(0 0 8px rgba(255,255,255,0.8))", "drop-shadow(0 0 2px rgba(255,255,255,0.5))"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut"
                      }}
                    />
                  </svg>
                  
                  {/* Icon */}
                  <div className="absolute inset-0 flex items-center justify-center">
                    <motion.span
                      className="text-white text-xl sm:text-2xl"
                      animate={{
                        scale: [1, 1.2, 1],
                        opacity: [0.8, 1, 0.8],
                        textShadow: ["0 0 4px rgba(255,255,255,0.3)", "0 0 8px rgba(255,255,255,0.6)", "0 0 4px rgba(255,255,255,0.3)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut"
                      }}
                    >
                      ★
                    </motion.span>
                  </div>

                  {/* Glowing dots around hexagon - only visible on hover */}
                  <motion.div
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-500"
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 0 }}
                    transition={{ duration: 0.5 }}
                  >
                    {[...Array(6)].map((_, i) => (
                      <motion.div
                        key={i}
                        className="absolute w-1.5 h-1.5 rounded-full bg-white"
                        style={{
                          left: `${50 + 45 * Math.cos(2 * Math.PI * i / 6)}%`,
                          top: `${50 + 45 * Math.sin(2 * Math.PI * i / 6)}%`,
                        }}
                        animate={{
                          opacity: [0.4, 1, 0.4],
                          scale: [0.8, 1.2, 0.8],
                        }}
                        transition={{
                          duration: 2,
                          repeat: Infinity,
                          delay: i * 0.3,
                          ease: "easeInOut"
                        }}
                      />
                    ))}
                  </motion.div>
                </div>
                <motion.p 
                  className="text-sm sm:text-base font-medium mt-3 text-white group-hover:text-white"
                  transition={{ duration: 0.3 }}
                >
                  Horóscopo Diario
                </motion.p>
                <div className="h-0.5 w-0 bg-gradient-to-r from-transparent via-white to-transparent group-hover:w-full transition-all duration-300 mt-1"></div>
              </motion.div>
            </a>
            
            <a href="#compatibilidad" className="block group">
              <motion.div 
                whileHover={{ 
                  scale: 1.08,
                  transition: { type: "spring", stiffness: 400, damping: 10 }
                }}
                className="flex flex-col items-center"
              >
                <div className="w-16 h-16 sm:w-20 sm:h-20 relative">
                  {/* Hexagon background with glow effect */}
                  <svg className="absolute inset-0" viewBox="0 0 100 100" fill="none">
                    <motion.path 
                      d="M50 0L93.3 25V75L50 100L6.7 75V25L50 0Z"
                      className="fill-pink-950/30 stroke-pink-400"
                      strokeWidth="1.5"
                      animate={{
                        strokeWidth: ["1.5", "2.5", "1.5"],
                        filter: ["drop-shadow(0 0 2px #f472b6)", "drop-shadow(0 0 8px #f472b6)", "drop-shadow(0 0 2px #f472b6)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 0.5
                      }}
                    />
                  </svg>
                  
                  {/* Icon */}
                  <div className="absolute inset-0 flex items-center justify-center">
                    <motion.span
                      className="text-pink-400 text-xl sm:text-2xl"
                      animate={{
                        scale: [1, 1.2, 1],
                        opacity: [0.8, 1, 0.8],
                        textShadow: ["0 0 4px rgba(244, 114, 182, 0.3)", "0 0 8px rgba(244, 114, 182, 0.6)", "0 0 4px rgba(244, 114, 182, 0.3)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 0.5
                      }}
                    >
                      ♥
                    </motion.span>
                  </div>

                  {/* Glowing dots around hexagon - only visible on hover */}
                  <motion.div
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-500"
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 0 }}
                    transition={{ duration: 0.5 }}
                  >
                    {[...Array(6)].map((_, i) => (
                      <motion.div
                        key={i}
                        className="absolute w-1.5 h-1.5 rounded-full bg-pink-400"
                        style={{
                          left: `${50 + 45 * Math.cos(2 * Math.PI * i / 6)}%`,
                          top: `${50 + 45 * Math.sin(2 * Math.PI * i / 6)}%`,
                        }}
                        animate={{
                          opacity: [0.4, 1, 0.4],
                          scale: [0.8, 1.2, 0.8],
                        }}
                        transition={{
                          duration: 2,
                          repeat: Infinity,
                          delay: i * 0.3,
                          ease: "easeInOut"
                        }}
                      />
                    ))}
                  </motion.div>
                </div>
                <motion.p 
                  className="text-sm sm:text-base font-medium mt-3 text-white group-hover:text-pink-400"
                  transition={{ duration: 0.3 }}
                >
                  Compatibilidad
                </motion.p>
                <div className="h-0.5 w-0 bg-gradient-to-r from-transparent via-pink-400 to-transparent group-hover:w-full transition-all duration-300 mt-1"></div>
              </motion.div>
            </a>
            
            <a href="#palma" className="block group">
              <motion.div 
                whileHover={{ 
                  scale: 1.08,
                  transition: { type: "spring", stiffness: 400, damping: 10 }
                }}
                className="flex flex-col items-center"
              >
                <div className="w-16 h-16 sm:w-20 sm:h-20 relative">
                  {/* Hexagon background with glow effect */}
                  <svg className="absolute inset-0" viewBox="0 0 100 100" fill="none">
                    <motion.path 
                      d="M50 0L93.3 25V75L50 100L6.7 75V25L50 0Z"
                      className="fill-purple-950/30 stroke-purple-400"
                      strokeWidth="1.5"
                      animate={{
                        strokeWidth: ["1.5", "2.5", "1.5"],
                        filter: ["drop-shadow(0 0 2px #c084fc)", "drop-shadow(0 0 8px #c084fc)", "drop-shadow(0 0 2px #c084fc)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 1
                      }}
                    />
                  </svg>
                  
                  {/* Icon */}
                  <div className="absolute inset-0 flex items-center justify-center">
                    <motion.span
                      className="text-purple-400 text-xl sm:text-2xl"
                      animate={{
                        scale: [1, 1.2, 1],
                        opacity: [0.8, 1, 0.8],
                        textShadow: ["0 0 4px rgba(192, 132, 252, 0.3)", "0 0 8px rgba(192, 132, 252, 0.6)", "0 0 4px rgba(192, 132, 252, 0.3)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 1
                      }}
                    >
                      ✋
                    </motion.span>
                  </div>

                  {/* Glowing dots around hexagon - only visible on hover */}
                  <motion.div
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-500"
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 0 }}
                    transition={{ duration: 0.5 }}
                  >
                    {[...Array(6)].map((_, i) => (
                      <motion.div
                        key={i}
                        className="absolute w-1.5 h-1.5 rounded-full bg-purple-400"
                        style={{
                          left: `${50 + 45 * Math.cos(2 * Math.PI * i / 6)}%`,
                          top: `${50 + 45 * Math.sin(2 * Math.PI * i / 6)}%`,
                        }}
                        animate={{
                          opacity: [0.4, 1, 0.4],
                          scale: [0.8, 1.2, 0.8],
                        }}
                        transition={{
                          duration: 2,
                          repeat: Infinity,
                          delay: i * 0.3,
                          ease: "easeInOut"
                        }}
                      />
                    ))}
                  </motion.div>
                </div>
                <motion.p 
                  className="text-sm sm:text-base font-medium mt-3 text-white group-hover:text-purple-400"
                  transition={{ duration: 0.3 }}
                >
                  Lectura de Palma
                </motion.p>
                <div className="h-0.5 w-0 bg-gradient-to-r from-transparent via-purple-400 to-transparent group-hover:w-full transition-all duration-300 mt-1"></div>
              </motion.div>
            </a>
            
            <a href="#tarot" className="block group">
              <motion.div 
                whileHover={{ 
                  scale: 1.08,
                  transition: { type: "spring", stiffness: 400, damping: 10 }
                }}
                className="flex flex-col items-center"
              >
                <div className="w-16 h-16 sm:w-20 sm:h-20 relative">
                  {/* Hexagon background with glow effect */}
                  <svg className="absolute inset-0" viewBox="0 0 100 100" fill="none">
                    <motion.path 
                      d="M50 0L93.3 25V75L50 100L6.7 75V25L50 0Z"
                      className="fill-amber-950/30 stroke-amber-400"
                      strokeWidth="1.5"
                      animate={{
                        strokeWidth: ["1.5", "2.5", "1.5"],
                        filter: ["drop-shadow(0 0 2px #fbbf24)", "drop-shadow(0 0 8px #fbbf24)", "drop-shadow(0 0 2px #fbbf24)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 1.5
                      }}
                    />
                  </svg>
                  
                  {/* Icon */}
                  <div className="absolute inset-0 flex items-center justify-center">
                    <motion.span
                      className="text-amber-400 text-xl sm:text-2xl"
                      animate={{
                        scale: [1, 1.2, 1],
                        opacity: [0.8, 1, 0.8],
                        textShadow: ["0 0 4px rgba(251, 191, 36, 0.3)", "0 0 8px rgba(251, 191, 36, 0.6)", "0 0 4px rgba(251, 191, 36, 0.3)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 1.5
                      }}
                    >
                      ☽
                    </motion.span>
                  </div>

                  {/* Glowing dots around hexagon - only visible on hover */}
                  <motion.div
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-500"
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 0 }}
                    transition={{ duration: 0.5 }}
                  >
                    {[...Array(6)].map((_, i) => (
                      <motion.div
                        key={i}
                        className="absolute w-1.5 h-1.5 rounded-full bg-amber-400"
                        style={{
                          left: `${50 + 45 * Math.cos(2 * Math.PI * i / 6)}%`,
                          top: `${50 + 45 * Math.sin(2 * Math.PI * i / 6)}%`,
                        }}
                        animate={{
                          opacity: [0.4, 1, 0.4],
                          scale: [0.8, 1.2, 0.8],
                        }}
                        transition={{
                          duration: 2,
                          repeat: Infinity,
                          delay: i * 0.3,
                          ease: "easeInOut"
                        }}
                      />
                    ))}
                  </motion.div>
                </div>
                <motion.p 
                  className="text-sm sm:text-base font-medium mt-3 text-white group-hover:text-amber-400"
                  transition={{ duration: 0.3 }}
                >
                  Tarot Virtual
                </motion.p>
                <div className="h-0.5 w-0 bg-gradient-to-r from-transparent via-amber-400 to-transparent group-hover:w-full transition-all duration-300 mt-1"></div>
              </motion.div>
            </a>
            
            <a href="#runas" className="block sm:col-span-1 col-span-2 group">
              <motion.div 
                whileHover={{ 
                  scale: 1.08,
                  transition: { type: "spring", stiffness: 400, damping: 10 }
                }}
                className="flex flex-col items-center"
              >
                <div className="w-16 h-16 sm:w-20 sm:h-20 relative">
                  {/* Hexagon background with glow effect */}
                  <svg className="absolute inset-0" viewBox="0 0 100 100" fill="none">
                    <motion.path 
                      d="M50 0L93.3 25V75L50 100L6.7 75V25L50 0Z"
                      className="fill-teal-950/30 stroke-teal-400"
                      strokeWidth="1.5"
                      animate={{
                        strokeWidth: ["1.5", "2.5", "1.5"],
                        filter: ["drop-shadow(0 0 2px #2dd4bf)", "drop-shadow(0 0 8px #2dd4bf)", "drop-shadow(0 0 2px #2dd4bf)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 2
                      }}
                    />
                  </svg>
                  
                  {/* Icon */}
                  <div className="absolute inset-0 flex items-center justify-center">
                    <motion.span
                      className="text-teal-400 text-xl sm:text-2xl"
                      animate={{
                        scale: [1, 1.2, 1],
                        opacity: [0.8, 1, 0.8],
                        textShadow: ["0 0 4px rgba(45, 212, 191, 0.3)", "0 0 8px rgba(45, 212, 191, 0.6)", "0 0 4px rgba(45, 212, 191, 0.3)"]
                      }}
                      transition={{
                        repeat: Infinity,
                        duration: 3,
                        ease: "easeInOut",
                        delay: 2
                      }}
                    >
                      ♖
                    </motion.span>
                  </div>

                  {/* Glowing dots around hexagon - only visible on hover */}
                  <motion.div
                    className="absolute inset-0 opacity-0 group-hover:opacity-100 transition-opacity duration-500"
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 0 }}
                    transition={{ duration: 0.5 }}
                  >
                    {[...Array(6)].map((_, i) => (
                      <motion.div
                        key={i}
                        className="absolute w-1.5 h-1.5 rounded-full bg-teal-400"
                        style={{
                          left: `${50 + 45 * Math.cos(2 * Math.PI * i / 6)}%`,
                          top: `${50 + 45 * Math.sin(2 * Math.PI * i / 6)}%`,
                        }}
                        animate={{
                          opacity: [0.4, 1, 0.4],
                          scale: [0.8, 1.2, 0.8],
                        }}
                        transition={{
                          duration: 2,
                          repeat: Infinity,
                          delay: i * 0.3,
                          ease: "easeInOut"
                        }}
                      />
                    ))}
                  </motion.div>
                </div>
                <motion.p 
                  className="text-sm sm:text-base font-medium mt-3 text-white group-hover:text-teal-400"
                  transition={{ duration: 0.3 }}
                >
                  Runas
                </motion.p>
                <div className="h-0.5 w-0 bg-gradient-to-r from-transparent via-teal-400 to-transparent group-hover:w-full transition-all duration-300 mt-1"></div>
              </motion.div>
            </a>
          </div>
        </motion.div>
      </div>
      
      <AuthModal isOpen={showAuthModal} onClose={() => setShowAuthModal(false)} />
    </section>
  );
}
